==> qore-0.9.3.1.tar.bz2: qore-0.9.3.1/docs/modules/SqlUtil/html/navtreedata.js <==
/*
@ @licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2017 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore SqlUtil Module Reference", "index.html", [
    [ "SqlUtil Module", "index.html", "index" ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"class_sql_util_1_1_abstract_table.html#a0e7864229ea23cdc835b1faaa9fbd46f",
"class_sql_util_1_1_columns.html",
"group__astparser__symbol__kind__constants.html#ga4278057ee77a07243389127bbdab0791",
"group__date__and__time__functions.html#ga9d2be4bc7d936dbe4881a6d2b3a45ad0",
"group__file__open__constants.html#ga9af988b09d302ec0ae8605d5610e1e9a",
"group__list__functions.html#ga98f4d58ff2aac802955588fab5e2e066",
"group__object__functions.html#gaaf374f86d44e428d57a23caee48374af",
"group__sql__cop__trunc__date__enum.html#ga7b5441c9b39b31615e264fa837ba78db",
"group__system__and__build__constants.html#ga981ec5d46693e04ec68a953c96950b97",
"group__x509__verification__constants.html#gaea4002870f0a1df88999dfc925243b95"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> qore-0.9.4.tar.bz2: qore-0.9.4/docs/modules/SqlUtil/html/navtreedata.js <==
/*
@ @licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2017 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore SqlUtil Module Reference", "index.html", [
    [ "SqlUtil Module", "index.html", "index" ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"class_sql_util_1_1_abstract_table.html#a01d23d0e7f8bb79c74940939c5664ddb",
"class_sql_util_1_1_abstract_table.html#af9486872afefc11541b9cfd7a1383585",
"group__astparser__declaration__kind__constants.html#ga46c276e00b43636d1012212c5b729df8",
"group__database__driver__constants.html#ga6cec46106d85f35a513ebb3d7b751cef",
"group__error__constants.html#gace017744be8d9255d2e4f2cf3acf2fdf",
"group__library__functions.html#ga62b13320abd1919d456e2cb84390b0b2",
"group__misc__functions.html#ga98e1d9690329e8c94f88b833af36ef72",
"group__signal__constants.html#ga943ce4334d5a4cfa3597c6c581e50b6c",
"group__string__functions.html#ga51cd422758d497338d9fe3aa1c9e3510",
"group__type__conversion__functions.html#gada40c7265689dbfa89579beff516489a"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
